@@ -5,11 +5,12 @@ import json
 from tqdm import tqdm
 class ArkaClient:
     # Initializes the ArkaClient with given RPC, REST and IPFS endpoints.
-    def __init__(self, rpc_url="http://localhost:26657", rest_url="http://localhost:1317", ipfs_url="http://127.0.0.1:8080", ipfs_api= "http://127.0.0.1:5001"):
+    def __init__(self, rpc_url="http://localhost:26657", rest_url="http://localhost:1317", ipfs_url="http://127.0.0.1:8080", ipfs_ip="164.92.97.19", ipfs_port=5001):
         self.rpc_url = rpc_url
         self.rest_url = rest_url
         self.ipfs_url = ipfs_url
-        self.ipfs_api = ipfs_api
+        self.ipfs_ip = ipfs_ip
+        self.ipfs_port = ipfs_port
     
     # query version w.r.t given version_id and repository_id
     def get_version_by_id(self, repository_id, version_id):
@@ -139,7 +140,8 @@ class ArkaClient:
         if not os.path.exists(path):
             raise FileNotFoundError(f"Path not found: {path}")
         
-        url = f"{self.ipfs_api}/api/v0/add"
+        # url = f"{self.ipfs_api}/api/v0/add"
+        url = f"http://{self.ipfs_ip}:{self.ipfs_port}/api/v0/add"
         is_dir = os.path.isdir(path)
 
         files = []
